import time
import board
import neopixel
import random
import adafruit_ble
import digitalio

from adafruit_ble import BLERadio
from adafruit_ble.advertising.standard import ProvideServicesAdvertisement
from adafruit_ble.services.standard.device_info import DeviceInfoService
from adafruit_ble_heart_rate import HeartRateService
from adafruit_led_animation.animation.pulse import Pulse
from adafruit_led_animation.sequence import AnimationSequence
from adafruit_led_animation.sequence import AnimateOnce
from audiopwmio import PWMAudioOut as AudioOut
from audiocore import WaveFile


#Sounds
def play_sound(filename):
    with open(path + filename, "rb") as wave_file:
        wave = WaveFile(wave_file)
        audio.play(wave)
        while audio.playing:
            pulse.animate()

path = "panic_sounds/"

#configure the speaker
speaker = digitalio.DigitalInOut(board.SPEAKER_ENABLE)
speaker.direction = digitalio.Direction.OUTPUT
speaker.value = True
audio = AudioOut(board.SPEAKER)

#lights
AQUA = (50, 255, 255)
BLACK = (0,0,0)

strip_pin = board.A1
strip_num_of_lights = 40
strip = neopixel.NeoPixel(strip_pin, strip_num_of_lights, brightness = 0.5, auto_write = True)

pixels_pin=board.NEOPIXEL
pixels_num_of_lights = 10
pixels = neopixel.NeoPixel(pixels_pin, pixels_num_of_lights, brightness = 0.5, auto_write = True)

# pulse = Pulse(pixels, speed=0.05, color=AQUA, period=2)
# pulse_strip1 = Pulse(strip, speed=0.05, color=AQUA, period=2)
# pulse_strip2 = Pulse(strip, speed=0.05, color=AQUA, period=4)
# pulse_strip3 = Pulse(strip, speed=0.05, color=AQUA, period=6)
# pulse_strip4 = Pulse(strip, speed=0.05, color=AQUA, period=8)
# pulse_strip5 = Pulse(strip, speed=0.05, color=AQUA, period=10)

#pulse = Pulse(pixels, speed=0.01, color=AQUA, period=10)
pulse = Pulse(strip, speed=0.1, color=AQUA, period=10)
pulse1 = Pulse(pixels, speed=0.01, color=AQUA, period=12)
animations  = AnimateOnce(pulse, pulse1)
# pulses = [Pulse(pixels, speed=0.01, color=AQUA, period=6),
# Pulse(pixels, speed=0.01, color=AQUA, period=8),
# Pulse(pixels, speed=0.01, color=AQUA, period=10)]
# animations = AnimationSequence(*pulses, advance_interval = 30)

#Bluetooth Setup
ble = adafruit_ble.BLERadio()

hr_connection = None

x = True

# Make a variable that is x = True

# Start with a fresh connection.
if ble.connected:
    time.sleep(1)

    for connection in ble.connections:
        if HeartRateService in connection:
            connection.disconnect()
        break


while x:
    print("Scanning...")
    time.sleep(1)


    for adv in ble.start_scan(ProvideServicesAdvertisement, timeout=5):
        if HeartRateService in adv.services:
            print("found a HeartRateService advertisement")
            hr_connection = ble.connect(adv)
            time.sleep(2)
            print("Connected")
            break

    ble.stop_scan()
    print("Stopped scan")
    time.sleep(0.1)

    if hr_connection and hr_connection.connected:
        print("Fetch connection")
        if DeviceInfoService in hr_connection:
            dis = hr_connection[DeviceInfoService]
            try:
                manufacturer = dis.manufacturer
            except AttributeError:
                manufacturer = "(Manufacturer Not specified)"
            try:
                model_number = dis.model_number
            except AttributeError:
                model_number = "(Model number not specified)"
            print("Device:", manufacturer, model_number)
        else:
            print("No device information")
        hr_service = hr_connection[HeartRateService]
        print("Location:", hr_service.location)
        x = False
        #might not need the x = False lol

    while hr_connection.connected:
            values = hr_service.measurement_values
            if values:
                bpm = (values.heart_rate)
                if bpm > 70:
                    print("You're having a panic attack lol - BPM:" + str(bpm))
                    play_sound("panic.wav")
                    #play_sound("panic.wav")
                elif bpm > 50 and bpm < 70:
                    strip.fill(BLACK)
                    print("You're chillin. BPM:" + str(bpm))
            #print(values)  # returns the full heart_rate data set
